'use server'

import { getPayload, PaginatedDocs } from 'payload'
import config from '@/payload.config'
import { Copy } from '@/payload-types'

type Props = {
  bookId: number,
  repositoryId: number
}
export const findCopiesOfBookInRepository = async (props: Props): Promise<PaginatedDocs<Copy> | null> => {
  const { bookId, repositoryId } = props

  const payloadConfig = await config
  const payload = await getPayload({ config: payloadConfig })

  try {
    const findResponse = (await payload.find({
      collection: 'copies',
      depth: 2,
      limit: 25,
      overrideAccess: false,
      where: {
        and: [
          {
            'repository.id': {
              equals: repositoryId
            }
          },
          {
            'book.id': {
              equals: bookId
            }
          },
        ]
      },
      select: {
        id: true,
        label: true,
        repository: true,
        book: true,
        holdRequests: true,
      },
      joins: {
        holdRequests: {
          limit: 100,
        },
      }
    })) as PaginatedDocs<Copy>

    return findResponse
  } catch (err) {
    console.log(err)
    return null
  }
} 
